mocks

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DeliveryAttemptRepository

type DeliveryAttemptRepository struct {
	mock.Mock
}

DeliveryAttemptRepository is an autogenerated mock type for the DeliveryAttemptRepository type

func (*DeliveryAttemptRepository) Find

Find provides a mock function with given fields: id

func (*DeliveryAttemptRepository) FindAll

FindAll provides a mock function with given fields: findOptions

func (*DeliveryAttemptRepository) Store

func (_m *DeliveryAttemptRepository) Store(tx hammer.TxRepository, deliveryAttempt *hammer.DeliveryAttempt) error

Store provides a mock function with given fields: tx, deliveryAttempt

type DeliveryAttemptService

type DeliveryAttemptService struct {
	mock.Mock
}

DeliveryAttemptService is an autogenerated mock type for the DeliveryAttemptService type

func (*DeliveryAttemptService) Find

Find provides a mock function with given fields: id

func (*DeliveryAttemptService) FindAll

func (_m *DeliveryAttemptService) FindAll(findOptions hammer.FindOptions) ([]hammer.DeliveryAttempt, error)

FindAll provides a mock function with given fields: findOptions

type DeliveryRepository

type DeliveryRepository struct {
	mock.Mock
}

DeliveryRepository is an autogenerated mock type for the DeliveryRepository type

func (*DeliveryRepository) Find

func (_m *DeliveryRepository) Find(id string) (hammer.Delivery, error)

Find provides a mock function with given fields: id

func (*DeliveryRepository) FindAll

func (_m *DeliveryRepository) FindAll(findOptions hammer.FindOptions) ([]hammer.Delivery, error)

FindAll provides a mock function with given fields: findOptions

func (*DeliveryRepository) FindToDispatch

func (_m *DeliveryRepository) FindToDispatch(limit int, offset int) ([]string, error)

FindToDispatch provides a mock function with given fields: limit, offset

func (*DeliveryRepository) Store

func (_m *DeliveryRepository) Store(tx hammer.TxRepository, delivery *hammer.Delivery) error

Store provides a mock function with given fields: tx, delivery

type DeliveryService

type DeliveryService struct {
	mock.Mock
}

DeliveryService is an autogenerated mock type for the DeliveryService type

func (*DeliveryService) Dispatch

func (_m *DeliveryService) Dispatch(delivery *hammer.Delivery, httpClient *http.Client) error

Dispatch provides a mock function with given fields: delivery, httpClient

func (*DeliveryService) Find

func (_m *DeliveryService) Find(id string) (hammer.Delivery, error)

Find provides a mock function with given fields: id

func (*DeliveryService) FindAll

func (_m *DeliveryService) FindAll(findOptions hammer.FindOptions) ([]hammer.Delivery, error)

FindAll provides a mock function with given fields: findOptions

func (*DeliveryService) FindToDispatch

func (_m *DeliveryService) FindToDispatch(limit int, offset int) ([]string, error)

FindToDispatch provides a mock function with given fields: limit, offset

type MessageRepository

type MessageRepository struct {
	mock.Mock
}

MessageRepository is an autogenerated mock type for the MessageRepository type

func (*MessageRepository) Delete

func (_m *MessageRepository) Delete(tx hammer.TxRepository, id string) error

Delete provides a mock function with given fields: tx, id

func (*MessageRepository) Find

func (_m *MessageRepository) Find(id string) (hammer.Message, error)

Find provides a mock function with given fields: id

func (*MessageRepository) FindAll

func (_m *MessageRepository) FindAll(findOptions hammer.FindOptions) ([]hammer.Message, error)

FindAll provides a mock function with given fields: findOptions

func (*MessageRepository) Store

func (_m *MessageRepository) Store(tx hammer.TxRepository, message *hammer.Message) error

Store provides a mock function with given fields: tx, message

type MessageService

type MessageService struct {
	mock.Mock
}

MessageService is an autogenerated mock type for the MessageService type

func (*MessageService) Create

func (_m *MessageService) Create(message *hammer.Message) error

Create provides a mock function with given fields: message

func (*MessageService) Delete

func (_m *MessageService) Delete(id string) error

Delete provides a mock function with given fields: id

func (*MessageService) Find

func (_m *MessageService) Find(id string) (hammer.Message, error)

Find provides a mock function with given fields: id

func (*MessageService) FindAll

func (_m *MessageService) FindAll(findOptions hammer.FindOptions) ([]hammer.Message, error)

FindAll provides a mock function with given fields: findOptions

type MigrationRepository

type MigrationRepository struct {
	mock.Mock
}

MigrationRepository is an autogenerated mock type for the MigrationRepository type

func (*MigrationRepository) Run

func (_m *MigrationRepository) Run() error

Run provides a mock function with given fields:

type SubscriptionRepository

type SubscriptionRepository struct {
	mock.Mock
}

SubscriptionRepository is an autogenerated mock type for the SubscriptionRepository type

func (*SubscriptionRepository) Delete

Delete provides a mock function with given fields: tx, id

func (*SubscriptionRepository) Find

Find provides a mock function with given fields: id

func (*SubscriptionRepository) FindAll

func (_m *SubscriptionRepository) FindAll(findOptions hammer.FindOptions) ([]hammer.Subscription, error)

FindAll provides a mock function with given fields: findOptions

func (*SubscriptionRepository) Store

func (_m *SubscriptionRepository) Store(tx hammer.TxRepository, subscription *hammer.Subscription) error

Store provides a mock function with given fields: tx, subscription

type SubscriptionService

type SubscriptionService struct {
	mock.Mock
}

SubscriptionService is an autogenerated mock type for the SubscriptionService type

func (*SubscriptionService) Create

func (_m *SubscriptionService) Create(subscription *hammer.Subscription) error

Create provides a mock function with given fields: subscription

func (*SubscriptionService) Delete

func (_m *SubscriptionService) Delete(id string) error

Delete provides a mock function with given fields: id

func (*SubscriptionService) Find

Find provides a mock function with given fields: id

func (*SubscriptionService) FindAll

func (_m *SubscriptionService) FindAll(findOptions hammer.FindOptions) ([]hammer.Subscription, error)

FindAll provides a mock function with given fields: findOptions

func (*SubscriptionService) Update

func (_m *SubscriptionService) Update(subscription *hammer.Subscription) error

Update provides a mock function with given fields: subscription

type TopicRepository

type TopicRepository struct {
	mock.Mock
}

TopicRepository is an autogenerated mock type for the TopicRepository type

func (*TopicRepository) Delete

func (_m *TopicRepository) Delete(tx hammer.TxRepository, id string) error

Delete provides a mock function with given fields: tx, id

func (*TopicRepository) Find

func (_m *TopicRepository) Find(id string) (hammer.Topic, error)

Find provides a mock function with given fields: id

func (*TopicRepository) FindAll

func (_m *TopicRepository) FindAll(findOptions hammer.FindOptions) ([]hammer.Topic, error)

FindAll provides a mock function with given fields: findOptions

func (*TopicRepository) Store

func (_m *TopicRepository) Store(tx hammer.TxRepository, topic *hammer.Topic) error

Store provides a mock function with given fields: tx, topic

type TopicService

type TopicService struct {
	mock.Mock
}

TopicService is an autogenerated mock type for the TopicService type

func (*TopicService) Create

func (_m *TopicService) Create(topic *hammer.Topic) error

Create provides a mock function with given fields: topic

func (*TopicService) Delete

func (_m *TopicService) Delete(id string) error

Delete provides a mock function with given fields: id

func (*TopicService) Find

func (_m *TopicService) Find(id string) (hammer.Topic, error)

Find provides a mock function with given fields: id

func (*TopicService) FindAll

func (_m *TopicService) FindAll(findOptions hammer.FindOptions) ([]hammer.Topic, error)

FindAll provides a mock function with given fields: findOptions

func (*TopicService) Update

func (_m *TopicService) Update(topic *hammer.Topic) error

Update provides a mock function with given fields: topic

type TxFactoryRepository

type TxFactoryRepository struct {
	mock.Mock
}

TxFactoryRepository is an autogenerated mock type for the TxFactoryRepository type

func (*TxFactoryRepository) New

New provides a mock function with given fields:

type TxRepository

type TxRepository struct {
	mock.Mock
}

TxRepository is an autogenerated mock type for the TxRepository type

func (*TxRepository) Commit

func (_m *TxRepository) Commit() error

Commit provides a mock function with given fields:

func (*TxRepository) Exec

func (_m *TxRepository) Exec(query string, arg interface{}) error

Exec provides a mock function with given fields: query, arg

func (*TxRepository) Rollback

func (_m *TxRepository) Rollback() error

Rollback provides a mock function with given fields:

Jump to